[evolvis-commits] r18360: tarent-imprint pending merges:↵ Thorsten Glaser 2012-04-18 install actual imprint into customisable location /etc/gforge/custom/↵ Thorsten Glaser 2012-04-18 split imprint off the file actually rendering it in a forge themed page↵ Thorsten Glaser 2012-04-18 add an About page

mirabilos at evolvis.org mirabilos at evolvis.org
Wed Apr 18 14:46:54 CEST 2012


Author: mirabilos
Date: 2012-04-18 14:46:53 +0200 (Wed, 18 Apr 2012)
New Revision: 18360

Added:
   trunk/gforge_base/evolvisforge-5.1/src/www/about/
   trunk/gforge_base/evolvisforge-5.1/src/www/about/index.php
   trunk/gforge_base/evolvisforge-5.1/src/www/impress/imprint.php
Modified:
   trunk/gforge_base/evolvisforge-5.1/src/packaging/install/web-apache2
   trunk/gforge_base/evolvisforge-5.1/src/www/impress/index.php
Log:
tarent-imprint pending merges:
  Thorsten Glaser 2012-04-18 install actual imprint into customisable location /etc/gforge/custom/
    Thorsten Glaser 2012-04-18 split imprint off the file actually rendering it in a forge themed page
    Thorsten Glaser 2012-04-18 add an About page

Modified: trunk/gforge_base/evolvisforge-5.1/src/packaging/install/web-apache2
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/packaging/install/web-apache2	2012-04-12 18:40:43 UTC (rev 18359)
+++ trunk/gforge_base/evolvisforge-5.1/src/packaging/install/web-apache2	2012-04-18 12:46:53 UTC (rev 18360)
@@ -1,5 +1,6 @@
 www                                 usr/share/@OLDPACKAGE@/
 www/index_std.php                   etc/@OLDPACKAGE@/custom/
+www/impress/imprint.php             etc/@OLDPACKAGE@/custom/
 utils/install-apache.sh             usr/share/@OLDPACKAGE@/bin/
 utils/manage-apache-config.sh	    usr/share/@OLDPACKAGE@/bin/
 etc/httpd.conf.d-fhs		    usr/share/@OLDPACKAGE@/etc/

Added: trunk/gforge_base/evolvisforge-5.1/src/www/about/index.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/www/about/index.php	                        (rev 0)
+++ trunk/gforge_base/evolvisforge-5.1/src/www/about/index.php	2012-04-18 12:46:53 UTC (rev 18360)
@@ -0,0 +1,59 @@
+<?php
+/*-
+ * About Evolvis page
+ *
+ * Copyright © 2012
+ *	Thorsten Glaser <t.glaser at tarent.de>
+ * All rights reserved.
+ *
+ * This file is part of FusionForge. FusionForge is free software;
+ * you can redistribute it and/or modify it under the terms of the
+ * GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the Licence, or (at your option)
+ * any later version.
+ *
+ * FusionForge is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with FusionForge; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
+require_once('../env.inc.php');
+require_once $gfcommon.'include/pre.php';
+require_once $gfcommon.'include/FusionForge.class.php';
+require_once $gfcommon.'pm/ProjectTaskSqlQueries.php';
+
+site_header(array(
+	'title' => _('About'),
+	'h1' => sprintf(_('About %s'), forge_get_config('forge_name')),
+    ));
+
+$ff = new FusionForge();
+
+printf(_('<p>The %1$s forge is running the %2$s software, version <b>%3$s</b>.</p>'),
+    forge_get_config('forge_name'), $ff->software_name, $ff->software_version);
+echo "\n";
+
+echo _('<p>Please also read the <a href="../impress/">imprint</a>.</p>');
+echo "\n";
+
+printf(_('<h2>About the %s software</h2>'), $ff->software_name);
+echo "\n";
+
+?>
+
+<!-- keep me in -->
+<p>The <a href="https://evolvis.org/projects/evolvis/">Evolvis Platform</a> by
+ <a href="https://www.tarent.de/">tarent solutions GmbH</a> uses <a
+ href="https://fusionforge.org/">FusionForge</a> technology on <a
+ href="http://www.debian.org/">Debian</a>.</p>
+
+<?php
+printf(_('<p><small>Minimum Unique Task/Tracker Item ID: <b>%d</b></small></p>'),
+    tasktracker_getminid());
+
+site_footer(array());

Added: trunk/gforge_base/evolvisforge-5.1/src/www/impress/imprint.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/www/impress/imprint.php	                        (rev 0)
+++ trunk/gforge_base/evolvisforge-5.1/src/www/impress/imprint.php	2012-04-18 12:46:53 UTC (rev 18360)
@@ -0,0 +1,82 @@
+<?php
+/*-
+ * Evolvis Impressum
+ *
+ * Copyright © 2007, 2010, 2011
+ *	tarent GmbH
+ * Copyright © 2012
+ *	Thorsten Glaser, tarent solutions GmbH
+ * All rights reserved.
+ *
+ * This file is part of EvolvisForge. EvolvisForge is free software;
+ * you can redistribute it and/or modify it under the terms of the
+ * GNU General Public License as published by the Free Software
+ * Foundation; either version 2 of the Licence, or (at your option)
+ * any later version.
+ *
+ * EvolvisForge is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with EvolvisForge; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *-
+ * Actual textual body of the Evolvis Imprint for this forge.
+ * Edit the file /etc/gforge/custom/imprint.php to change it.
+ */
+
+?>
+
+<p>tarent solutions GmbH<br />
+Rochusstraße 2-4<br />
+53123 Bonn</p>
+<p>Tel.: +49 228 54881-313<br />
+Web: <a href="https://www.tarent.de/">https://www.tarent.de/</a><br />
+Mail: <a href="mailto:info at tarent.de">info at tarent.de</a></p>
+
+<p>Geschäftsführer:</p><ul>
+ <li>Elmar Geese</li>
+ <li>Boris Esser</li>
+</ul><p>Rechtsform: GmbH<br />
+Amtsgericht Bonn, HRB 51 68<br />
+USt-IdNr.: DE122264941</p>
+
+<hr />
+
+<p>CEO:</p><ul>
+ <li>Elmar Geese</li>
+ <li>Boris Esser</li>
+</ul><p>Form of Organisation: GmbH<br />
+Local Court Bonn, HRB 51 68<br />
+VAT ID: DE122264941</p>
+
+<hr />
+
+<p>V.i.S.d.P.: Boris Esser, tarent solutions GmbH</p>
+
+<p>Rechtlicher Hinweis zu angebrachten Links: Die auf unserer
+ Internetseite angebrachten Links wurden nach besten Wissen und Gewissen
+ auf Rechtgültigkeit geprüft. Den Inhalt dieser Seiten macht sich die
+ <b>tarent solutions GmbH</b> hiermit ausdrücklich <strong>nicht</strong>
+ zu eigen und distanziert sich von deren Inhalt. Das Internet (und damit
+ auch einzelne Webseiten) ist kein statisches Medium. Aussagen auf gelinkten
+ Seiten können sich daher nachträglich ändern. Für uns ist es technisch
+ und menschlich nicht möglich, permanent externe Seiten zu überprüfen.</p>
+
+<p>(Siehe hierzu auch das Urteil vom 12. Mai 1998 - 312 O 85/98 des
+ Landgerichtes Hamburg.)</p>
+
+<p>Legal information concerning the links installed on this website:
+ The legal validity of the links installed on this website has been
+ checked to the best of our knowledge and conscience. <b>tarent solutions
+ GmbH</b> does <strong>not</strong> adopt the content of these linked
+ pages as its own and expressly dissociates itself from said content.
+ The Internet (and thus also individual websites) is not a static
+ medium. Statements that appear on linked pages may therefore change
+ subsequently. It is not possible for us, either technically or
+ personally, to permanently check external pages.</p>
+
+<p>(Concerning this, see the decision reached on 12 May 1998 -
+ 312 O 85/98 by the Regional Court of Hamburg.)</p>

Modified: trunk/gforge_base/evolvisforge-5.1/src/www/impress/index.php
===================================================================
--- trunk/gforge_base/evolvisforge-5.1/src/www/impress/index.php	2012-04-12 18:40:43 UTC (rev 18359)
+++ trunk/gforge_base/evolvisforge-5.1/src/www/impress/index.php	2012-04-18 12:46:53 UTC (rev 18360)
@@ -1,84 +1,43 @@
 <?php
-/**
+/*-
  * Evolvis Impressum
  *
- * Copyright © 2007, 2010, 2011 tarent GmbH
+ * Copyright © 2012
+ *	Thorsten Glaser <t.glaser at tarent.de>
+ * All rights reserved.
  *
- * This file is part of Evolvis. Evolvis is free software;
+ * This file is part of FusionForge. FusionForge is free software;
  * you can redistribute it and/or modify it under the terms of the
  * GNU General Public License as published by the Free Software
- * Foundation; either version 2 of the License, or (at your option)
+ * Foundation; either version 2 of the Licence, or (at your option)
  * any later version.
  *
  * Evolvis is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ *-
+ * Load the actual imprint for this forge instance.
  */
 
 require_once('../env.inc.php');
-require_once $gfwww.'include/pre.php';    // Initial db and session library, opens session
+require_once $gfcommon.'include/pre.php';
 
-$HTML->header(array('title'=>_('Welcome')));
+$bn = 'imprint.php';
+$fn = forge_get_config('custom_path') . '/' . $bn;
+if (!file_exists($fn)) {
+	$fn = $gfwww . '/impress/' . $bn;
+}
 
-?>
+site_header(array(
+	'title' => _('Imprint'),
+	'h1' => 'Impressum / Imprint',
+    ));
 
-<p>tarent solutions GmbH<br />
-Rochusstraße 2-4<br />
-53123 Bonn</p>
-<p>Tel.: +49 228 54881-313<br />
-Web: <a href="https://www.tarent.de/">https://www.tarent.de/</a><br />
-Mail: <a href="mailto:info at tarent.de">info at tarent.de</a></p>
+include($fn);
 
-<p>Geschäftsführer:</p><ul>
- <li>Elmar Geese</li>
- <li>Boris Esser</li>
-</ul><p>Rechtsform: GmbH<br />
-Amtsgericht Bonn, HRB 51 68<br />
-USt-IdNr.: DE122264941</p>
-
-<hr />
-
-<p>CEO:</p><ul>
- <li>Elmar Geese</li>
- <li>Boris Esser</li>
-</ul><p>Form of Organisation: GmbH<br />
-Local Court Bonn, HRB 51 68<br />
-VAT ID: DE122264941</p>
-
-<hr />
-
-<p>V.i.S.d.P.: Boris Esser, tarent solutions GmbH</p>
-
-<p>Rechtlicher Hinweis zu angebrachten Links: Die auf unserer
- Internetseite angebrachten Links wurden nach besten Wissen und Gewissen
- auf Rechtgültigkeit geprüft. Den Inhalt dieser Seiten macht sich die
- <b>tarent solutions GmbH</b> hiermit ausdrücklich <strong>nicht</strong>
- zu eigen und distanziert sich von deren Inhalt. Das Internet (und damit
- auch einzelne Webseiten) ist kein statisches Medium. Aussagen auf gelinkten
- Seiten können sich daher nachträglich ändern. Für uns ist es technisch
- und menschlich nicht möglich, permanent externe Seiten zu überprüfen.</p>
-
-<p>(Siehe hierzu auch das Urteil vom 12. Mai 1998 - 312 O 85/98 des
- Landgerichtes Hamburg.)</p>
-
-<p>Legal information concerning the links installed on this website:
- The legal validity of the links installed on this website has been
- checked to the best of our knowledge and conscience. <b>tarent solutions
- GmbH</b> does <strong>not</strong> adopt the content of these linked
- pages as its own and expressly dissociates itself from said content.
- The Internet (and thus also individual websites) is not a static
- medium. Statements that appear on linked pages may therefore change
- subsequently. It is not possible for us, either technically or
- personally, to permanently check external pages.</p>
-
-<p>(Concerning this, see the decision reached on 12 May 1998 -
- 312 O 85/98 by the Regional Court of Hamburg.)</p>
-
-<?php
-$HTML->footer(array());
-?>
+site_footer(array());
@@ -1,84 +1,43 @@
  * any later version.
  *
- * Evolvis is distributed in the hope that it will be useful,
+ * FusionForge is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -1,84 +1,43 @@
  *
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
+ * with FusionForge; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.



More information about the evolvis-commits mailing list